@@ -2,7 +2,7 @@
 
 /*  Monkey HTTP Server
  *  ==================
- *  Copyright 2001-2014 Monkey Software LLC <eduardo@monkey.io>
+ *  Copyright 2001-2015 Monkey Software LLC <eduardo@monkey.io>
  *  Copyright (C) 2012-2013, Lauri Kasanen
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,34 +20,51 @@
 
 #include "cgi.h"
 
-struct cgi_request *cgi_req_create(int fd, int socket, struct session_request *sr,
-					struct client_session *cs)
+struct cgi_request *cgi_req_create(int fd, int socket,
+                                   struct mk_http_request *sr,
+                                   struct mk_http_session *cs)
 {
-    struct cgi_request *newcgi = mk_api->mem_alloc_z(sizeof(struct cgi_request));
-    if (!newcgi) return NULL;
+    struct cgi_request *cgi;
 
-    newcgi->fd = fd;
-    newcgi->socket = socket;
-    newcgi->sr = sr;
-    newcgi->cs = cs;
+    cgi = mk_api->mem_alloc_z(sizeof(struct cgi_request));
+    if (!cgi) {
+        return NULL;
+    }
 
-    return newcgi;
+    cgi->fd = fd;
+    cgi->socket = socket;
+    cgi->sr = sr;
+    cgi->cs = cs;
+    cgi->hangup = MK_TRUE;
+    cgi->active = MK_TRUE;
+    cgi->in_len = 0;
+
+    cgi->event.mask   = MK_EVENT_EMPTY;
+    cgi->event.status = MK_EVENT_NONE;
+
+    return cgi;
 }
 
 void cgi_req_add(struct cgi_request *r)
 {
-    struct mk_list *list = pthread_getspecific(cgi_request_list);
+    struct mk_list *list;
 
-    mk_bug(!list);
+    list = pthread_getspecific(cgi_request_list);
     mk_list_add(&r->_head, list);
 }
 
 int cgi_req_del(struct cgi_request *r)
 {
-    if (!r) return 1;
+    PLUGIN_TRACE("Delete request child_fd=%i child_pid=%lu",
+                 r->fd, r->child);
 
     mk_list_del(&r->_head);
-    mk_api->mem_free(r);
+    if (r->active == MK_FALSE) {
+        mk_api->sched_event_free(&r->event);
+    }
+    else {
+        mk_mem_free(r);
+    }
 
     return 0;
 }
