@@ -2,7 +2,7 @@
 
 /*  Monkey HTTP Server
  *  ==================
- *  Copyright 2001-2014 Monkey Software LLC <eduardo@monkey.io>
+ *  Copyright 2001-2015 Monkey Software LLC <eduardo@monkey.io>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -21,8 +21,8 @@
 #ifndef MK_LOGGER_H
 #define MK_LOGGER_H
 
-#include "MKPlugin.h"
 #include <stdio.h>
+#include <monkey/mk_api.h>
 
 #define MK_LOGGER_PIPE_LIMIT 0.75
 #define MK_LOGGER_TIMEOUT_DEFAULT 3
@@ -37,16 +37,16 @@ FILE *mk_logger_master_stderr;
 pthread_key_t cache_content_length;
 pthread_key_t cache_status;
 pthread_key_t cache_ip_str;
+pthread_key_t cache_iov;
 
 struct log_target
 {
-    /* Pipes */
-    int fd_access[2];
-    int fd_error[2];
+    struct mk_event event;
 
-    /* File paths */
-    char *file_access;
-    char *file_error;
+    /* Pipes */
+    int is_ok;
+    int pipe[2];
+    char *file;
 
     struct host *host;
     struct mk_list _head;
